@@ -78,9 +78,10 @@ class Deployment(_defaults_.Defaults):
 
 		# deployment.
 		if not Files.exists(f"{self.root}/deployment"): os.mkdir(f"{self.root}/deployment")
-		clean_root = gfp.clean(self.library) # <== note the library change instead of root.
+		clean_root = gfp.clean(self.library, remove_last_slash=True, remove_double_slash=True) # <== note the library change instead of root.
 		replacements = {
 			"***ROOT***":clean_root, 
+			"***USER***":self.user, 
 			"***DOMAIN***":self.domain,
 			"***DATABASE***":self.database_path,
 			"***syst3m.defaults.vars.user***":syst3m.defaults.vars.user,
